@@ -202,7 +202,7 @@ extern unsigned long long int strtoull (__const char *__restrict __nptr,
 
 
 #if 0
-/*#ifdef __USE_GNU*/
+#ifdef __USE_GNU
 /* The concept of one static locale per category is not very well
    thought out.  Many applications will need to process its data using
    information from several different locales.  Another application is
@@ -250,8 +250,10 @@ extern long double __strtold_l (__const char *__restrict __nptr,
 				char **__restrict __endptr,
 				__locale_t __loc) __THROW;
 #endif /* GNU */
+#endif /* 0 */
 
 
+#if 0
 /* The internal entry points for `strtoX' take an extra flag argument
    saying whether or not to parse locale-dependent number grouping.  */
 
@@ -296,8 +298,10 @@ extern unsigned long long int __strtoull_internal (__const char *
 #  define __strtoull_internal_defined	1
 # endif
 #endif /* GCC */
+#endif /* 0 */
 
 #ifdef __USE_EXTERN_INLINES
+#if 0
 /* Define inline functions which call the internal entry points.  */
 
 extern __inline double
@@ -360,6 +364,7 @@ strtoull (__const char * __restrict __nptr, char **__restrict __endptr,
   return __strtoull_internal (__nptr, __endptr, __base, 0);
 }
 # endif
+#endif /* 0 */
 
 extern __inline double
 atof (__const char *__nptr) __THROW
@@ -579,7 +584,12 @@ extern void abort (void) __THROW __attribute__ ((__noreturn__));
 extern int atexit (void (*__func) (void)) __THROW;
 
 /* The following is used by uClibc in atexit.c and sysconf.c */
-#define __UCLIBC_MAX_ATEXIT     20
+/* We have no limit when __UCLIBC_DYNAMIC_ATEXIT__ is enabled.  */
+#ifdef __UCLIBC_DYNAMIC_ATEXIT__
+# define __UCLIBC_MAX_ATEXIT     INT_MAX
+#else
+# define __UCLIBC_MAX_ATEXIT     20
+#endif
 
 
 #ifdef	__USE_MISC
@@ -737,6 +747,7 @@ __extension__ extern lldiv_t lldiv (long long int __numer,
 #endif
 
 
+#if 0
 #ifdef __UCLIBC_HAS_FLOATS__
 #if defined __USE_SVID || defined __USE_XOPEN_EXTENDED
 /* Convert floating point numbers to strings.  The returned values are
@@ -787,6 +798,7 @@ extern int qfcvt_r (long double __value, int __ndigit,
 # endif	/* misc */
 #endif	/* use MISC || use X/Open Unix */
 #endif /* __UCLIBC_HAS_FLOATS__ */
+#endif
 
 #ifdef __UCLIBC_HAS_WCHAR__
 /* Return the length of the multibyte character
